Reachability Plots
A reachability plot displays the points as vertical bars, were the height is the
reachability distance between two consecutive points.
Reachability distances can be undefined when a point does not have enough
neighbors in the epsilon neighborhood. We represent these undefined cases as Inf
and represent them in the plot as a dashed line.
If many dashed lines show up for OPTICS then you need to increase eps there.
The reachability distance for the first
point is by definition not defined (it has no preceding point).
The central idea behind reachability plots is that the ordering in which
points are plotted identifies underlying hierarchical density
representation as mountains and valleys of high and low reachability distance.
Different hierarchical representations, such as dendrograms or reachability
plots, may be preferable depending on the context. In smaller datasets,
cluster memberships may be more easily identifiable through a dendrogram
representation, particularly is the user is already familiar with tree-like
representations. For larger datasets however, a reachability plot may be
preferred for visualizing macro-level density relationships.
Reachability Plots for OPTICS
The original ordering algorithm OPTICS as described by Ankerst et al (1999)
introduced the notion of reachability plots.
OPTICS linearly orders the data points such that points
which are spatially closest become neighbors in the ordering. Valleys
represent clusters, which can be represented hierarchically. Although the
ordering is crucial to the structure of the reachability plot, its important
to note that OPTICS, like DBSCAN, is not entirely deterministic and, just
like the dendrogram, isomorphisms may exist.
Reachability plots were shown to essentially convey the same information as
the more traditional dendrogram structure by Sanders et al (2003).
A variety of cluster extraction methods have been proposed using
reachability plots. Because both cluster extraction depend directly on the
ordering OPTICS produces, they are part of the optics() interface.
Nonetheless, reachability plots can be created directly from other types of
linkage trees, and vice versa.